@@ -1,4 +1,4 @@
-from ParallelPyFrontend.parallelsdk.pllai_data_toolbox import data_port_tools, optimizer_data_port_tools
+from parallelsdk.pllai_data_toolbox import data_port_tools, optimizer_data_port_tools
 
 
 def DataAndPorts(model_name, model_type):
