@@ -1,4 +1,4 @@
-from ParallelPyFrontend.parallelsdk.pllai_evolutionary_toolbox import evolutionary_problem, optimizer_evolutionary_model
+from parallelsdk.pllai_evolutionary_toolbox import evolutionary_problem, optimizer_evolutionary_model
 
 
 def EvolutionaryModel(model_name, model_type):
