@@ -1,9 +1,10 @@
-from ParallelPyFrontend.parallelsdk.pllai_mp_toolbox import optimizer_mp_model
+from parallelsdk.pllai_mp_toolbox import optimizer_mp_model
 
 
 def Infinity():
     return optimizer_mp_model.infinity()
 
+
 def MPModel(model_name, model_type=optimizer_mp_model.OptimizerModelType.UNDEF):
     """Builds and returns a new instance of a Mathematical Programming (MP)
     model. The caller can specify the type of model (e.g., LP, MIP) which is,
