@@ -1,6 +1,6 @@
-from ParallelPyFrontend.parallelsdk.pllai_mp_toolbox import constraints, mp_model, variables
-from ParallelPyFrontend.parallelsdk.proto import linear_model_pb2, optimizer_model_pb2, optilab_pb2
-from ParallelPyFrontend.parallelsdk import parallel_model
+from parallelsdk.pllai_mp_toolbox import constraints, mp_model, variables
+from parallelsdk.proto import linear_model_pb2, optimizer_model_pb2, optilab_pb2
+from parallelsdk import parallel_model
 
 from enum import Enum
 import logging
