@@ -1,7 +1,6 @@
-from ParallelPyFrontend.parallelsdk import connector_factory
-from ParallelPyFrontend.parallelsdk.pllai_routing_toolbox import routing_problem
-from ParallelPyFrontend.parallelsdk.pllai_scheduling_toolbox import scheduling_problem, \
-    employees_scheduling_to_vrp_connector
+from parallelsdk import connector_factory
+from parallelsdk.pllai_routing_toolbox import routing_problem
+from . import scheduling_problem, employees_scheduling_to_vrp_connector
 
 
 class SchedulingConnectorFactory(connector_factory.ConnectoryFactory):
