@@ -1,4 +1,4 @@
-from ParallelPyFrontend.parallelsdk.pllai_scheduling_toolbox import scheduling_problem, optimizer_scheduling_model
+from . import scheduling_problem, optimizer_scheduling_model
 
 
 def SchedulingModel(model_name, model_type):
